require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_activedirectoryauditruleentry',
  dscmeta_resource_friendly_name: 'ActiveDirectoryAuditRuleEntry',
  dscmeta_resource_name: 'ActiveDirectoryAuditRuleEntry',
  dscmeta_module_name: 'AccessControlDSC',
  dscmeta_module_version: '1.4.1',
  docs: 'The DSC ActiveDirectoryAuditRuleEntry resource type.
         Automatically generated from version 1.4.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_force: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the rights defined should be enforced. Will remove any rights not explicitly defined in the configuration for the path.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_distinguishedname: {
      type: 'String',
      desc: 'Indicates the Distinguished Name value for the target Active Directory Object.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_accesscontrollist: {
      type: "Array[Struct[{
              accesscontrolentry => Array[Struct[{
                cim_instance_type => 'ActiveDirectoryAuditRule',
                inheritedobjecttype => Optional[String],
                ensure => Enum['Present', 'Absent'],
                objecttype => Optional[String],
                auditflags => Enum['Success', 'Failure'],
                activedirectoryrights => Array[Enum['AccessSystemSecurity', 'CreateChild', 'Delete', 'DeleteChild', 'DeleteTree', 'ExtendedRight', 'GenericAll', 'GenericExecute', 'GenericRead', 'GenericWrite', 'ListChildren', 'ListObject', 'ReadControl', 'ReadProperty', 'Self', 'WriteDacl', 'WriteOwner', 'WriteProperty']],
                inheritancetype => Optional[Enum['All', 'Children', 'Descendents', 'None', 'SelfAndChildren']]
              }]],
              forceprincipal => Optional[Boolean],
              principal => String,
            }]]",
      desc: 'Indicates the access control information in the form of an array of instances of the ActiveDirectoryAuditRuleList CIM class.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'ActiveDirectorySystemAccessControlList[]',
      mof_is_embedded: true,
    },
  },
)
