require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_filesystemauditruleentry',
  dscmeta_resource_friendly_name: 'FileSystemAuditRuleEntry',
  dscmeta_resource_name: 'FileSystemAuditRuleEntry',
  dscmeta_module_name: 'AccessControlDSC',
  dscmeta_module_version: '1.4.1',
  docs: 'The DSC FileSystemAuditRuleEntry resource type.
         Automatically generated from version 1.4.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_path: {
      type: 'String',
      desc: 'Indicates the path to the target item.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_auditrulelist: {
      type: "Array[Struct[{
              auditruleentry => Array[Struct[{
                auditflags => Enum['None', 'Success', 'Failure'],
                inheritance => Enum['This folder only', 'This folder subfolders and files', 'This folder and subfolders', 'This folder and files', 'Subfolders and files only', 'Subfolders only', 'Files only'],
                ensure => Enum['Present', 'Absent'],
                cim_instance_type => 'FileSystemAuditRule',
                filesystemrights => Array[Enum['AppendData', 'ChangePermissions', 'CreateDirectories', 'CreateFiles', 'Delete', 'DeleteSubdirectoriesAndFiles', 'ExecuteFile', 'FullControl', 'ListDirectory', 'Modify', 'Read', 'ReadAndExecute', 'ReadAttributes', 'ReadData', 'ReadExtendedAttributes', 'ReadPermissions', 'Synchronize', 'TakeOwnership', 'Traverse', 'Write', 'WriteAttributes', 'WriteData', 'WriteExtendedAttributes']]
              }]],
              principal => String,
              forceprincipal => Boolean,
            }]]",
      desc: 'Indicates the audit rule information in the form of an array of instances of the FileSystemAuditRuleList CIM class.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'FileSystemAuditRuleList[]',
      mof_is_embedded: true,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_force: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the audit rules defined should be enforced. Will remove any audit rules not explicitly defined in the configuration for the path.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
