require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_registryaccessentry',
  dscmeta_resource_friendly_name: 'RegistryAccessEntry',
  dscmeta_resource_name: 'RegistryAccessEntry',
  dscmeta_module_name: 'AccessControlDSC',
  dscmeta_module_version: '1.4.1',
  docs: 'The DSC RegistryAccessEntry resource type.
         Automatically generated from version 1.4.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_force: {
      type: 'Optional[Boolean]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'String',
      desc: 'Indicates the path to the target item.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_accesscontrollist: {
      type: "Array[Struct[{
              accesscontrolentry => Array[Struct[{
                accesscontroltype => Optional[Enum['Allow', 'Deny']],
                rights => Optional[Array[Enum['ChangePermissions', 'CreateLink', 'CreateSubKey', 'Delete', 'EnumerateSubKeys', 'ExecuteKey', 'FullControl', 'Notify', 'QueryValues', 'ReadKey', 'ReadPermissions', 'SetValue', 'TakeOwnership', 'WriteKey']]],
                inheritance => Optional[Enum['This Key Only', 'This Key and Subkeys', 'SubKeys Only']],
                ensure => Optional[Enum['Present', 'Absent']],
                cim_instance_type => 'AccessControlEntry'
              }]],
              forceprincipal => Optional[Boolean],
              principal => Optional[String],
            }]]",
      desc: 'Indicates the access control information in the form of an array of instances of the RegistryRule CIM class.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'AccessControlList[]',
      mof_is_embedded: true,
    },
  },
)
